==========================================
``psyclone.psyir.nodes.commentable_mixin``
==========================================

.. automodule:: psyclone.psyir.nodes.commentable_mixin

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.commentable_mixin


Classes
=======

- :py:class:`CommentableMixin`:
  Mixin that adds the Commentable trait into a PSyIR node. It provides


.. autoclass:: CommentableMixin
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: CommentableMixin
      :parts: 1
